local Talented = Talented
local GameTooltip = GameTooltip
local TOOLTIP_TALENT_RANK = TOOLTIP_TALENT_RANK
local TOOLTIP_TALENT_TIER_POINTS = TOOLTIP_TALENT_TIER_POINTS
local TOOLTIP_TALENT_PREREQ = TOOLTIP_TALENT_PREREQ
local TOOLTIP_TALENT_NEXT_RANK = TOOLTIP_TALENT_NEXT_RANK
local GREEN_FONT_COLOR = GREEN_FONT_COLOR

local L = AceLibrary("AceLocale-2.2"):new("Talented")

local function addline(line, color, split)
	GameTooltip:AddLine(line, color.r, color.g, color.b, split)
end

local function add2line(left, right)
	GameTooltip:AddDoubleLine(left, right, GREEN_FONT_COLOR.r, GREEN_FONT_COLOR.g, GREEN_FONT_COLOR.b, GREEN_FONT_COLOR.r, GREEN_FONT_COLOR.g, GREEN_FONT_COLOR.b)
end

function Talented:SetTooltipInfo(frame, tab, index)
	if not GameTooltip:IsOwned(frame) then
		GameTooltip:SetOwner(frame, "ANCHOR_RIGHT")
	end
	
	local tree = self.talents[self.viewclass][tab]
	local info = tree.talents[index].info
	local tier = (info.row - 1) * 5
	local value = self.template[tab][index]
	GameTooltip:ClearLines()
	addline(info.name, HIGHLIGHT_FONT_COLOR)
	addline(TOOLTIP_TALENT_RANK:format(value, info.ranks), HIGHLIGHT_FONT_COLOR)
	if info.prereqs then
		for _, req in ipairs(info.prereqs) do
			local o = tree.talents[req.source].info
			local color
			if self.template[tab][req.source] == o.ranks then
				color = GREEN_FONT_COLOR
			else
				color = RED_FONT_COLOR
			end
			addline(TOOLTIP_TALENT_PREREQ:format(o.ranks, o.name), color)
		end
	end
	if tier >= 1 then
		local color
		if self:GetTalentTabCount(self.template, tab) >= tier then
			color = GREEN_FONT_COLOR
		else
			color = RED_FONT_COLOR
		end
		addline(TOOLTIP_TALENT_TIER_POINTS:format(tier, tree.info.name), color)
	end
	if info.tips then
		if value > 0 then
			addline(info.tips[value], NORMAL_FONT_COLOR, true)
		end
		if value < info.ranks then
			addline(TOOLTIP_TALENT_NEXT_RANK, HIGHLIGHT_FONT_COLOR)
			addline(info.tips[value + 1], NORMAL_FONT_COLOR, true)
		end
	else
		addline(L["Effective tooltip information not available"], RED_FONT_COLOR)
	end
	local s = self:GetTalentState(self.template, tab, index)
	if self.mode == "edit" then
		if self.template == self.current then
			if s == "available" or s == "empty" then
				addline(TOOLTIP_TALENT_LEARN, GREEN_FONT_COLOR)
			end
		elseif s == "full" then
			addline(L["Right-click to unlearn"], GREEN_FONT_COLOR)
		elseif s == "available" then
			add2line(TOOLTIP_TALENT_LEARN, L["Right-click to unlearn"])
		elseif s == "empty" then
			addline(TOOLTIP_TALENT_LEARN, GREEN_FONT_COLOR)
		end
	end
	GameTooltip:Show()
end

function Talented:HideTooltipInfo()
	GameTooltip:Hide()
end
